<?php

namespace Litecms\Tenders\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\Tenders\Interfaces\TenderRepositoryInterface;

class TenderController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Litecms\Tender\Interfaces\TenderRepositoryInterface $tender
     *
     * @return type
     */
    public function __construct(TenderRepositoryInterface $tender)
    {
        $this->middleware('web');
        $this->setupTheme(config('theme.themes.public.theme'), config('theme.themes.public.layout'));

        $this->repository = $tender;
        parent::__construct();
    }

    /**
     * Show tender's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $tenders = $this->repository
            ->pushCriteria(new \Litecms\Tenders\Repositories\Criteria\TenderPublicCriteria())
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        return $this->theme->of('tenders::public.tender.index', compact('tenders'))->render();
    }

    /**
     * Show tender.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $tender = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('tenders::public.tender.show', compact('tender'))->render();
    }
}
