<?php

namespace Litecms\Tenders\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Form;
use Litecms\Tenders\Http\Requests\TenderUserWebRequest;
use Litecms\Tenders\Interfaces\TenderRepositoryInterface;
use Litecms\Tenders\Models\Tender;

class TenderUserController extends BaseController
{
    /**
     * The authentication guard that should be used.
     *
     * @var string
     */
    protected $guard = 'web';

    /**
     * Initialize tender controller.
     *
     * @param type TenderRepositoryInterface $tender
     *
     * @return type
     */
    public function __construct(TenderRepositoryInterface $tender)
    {
        $this->middleware('web');
        $this->middleware('auth:web');
        $this->setupTheme(config('theme.themes.user.theme'), config('theme.themes.user.layout'));

        $this->repository = $tender;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(TenderUserWebRequest $request)
    {
        $this->repository->pushCriteria(new \Litecms\Tenders\Repositories\Criteria\TenderUserCriteria());
        $tenders = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        $this->theme->prependTitle(trans('tenders::tender.names').' :: ');

        return $this->theme->of('tenders::user.tender.index', compact('tenders'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param Tender $tender
     *
     * @return Response
     */
    public function show(TenderUserWebRequest $request, Tender $tender)
    {
        Form::populate($tender);

        return $this->theme->of('tenders::user.tender.show', compact('tender'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(TenderUserWebRequest $request)
    {

        $tender = $this->repository->newInstance([]);
        Form::populate($tender);

        return $this->theme->of('tenders::user.tender.create', compact('tender'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(TenderUserWebRequest $request)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $tender = $this->repository->create($attributes);

            return redirect(trans_url('/user/tenders/tender'))
                -> with('message', trans('messages.success.created', ['Module' => trans('tenders::tender.name')]))
                -> with('code', 201);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param Tender $tender
     *
     * @return Response
     */
    public function edit(TenderUserWebRequest $request, Tender $tender)
    {

        Form::populate($tender);

        return $this->theme->of('tenders::user.tender.edit', compact('tender'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param Tender $tender
     *
     * @return Response
     */
    public function update(TenderUserWebRequest $request, Tender $tender)
    {
        try {
            $this->repository->update($request->all(), $tender->getRouteKey());

            return redirect(trans_url('/user/tenders/tender'))
                ->with('message', trans('messages.success.updated', ['Module' => trans('tenders::tender.name')]))
                ->with('code', 204);

        } catch (Exception $e) {
            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(TenderUserWebRequest $request, Tender $tender)
    {
        try {
            $this->repository->delete($tender->getRouteKey());
            return response()->json([
                'message'  => trans('messages.success.deleted', ['Module' => trans('tenders::tender.name')]),
                'code'     => 202,
                'redirect' => trans_url('/user/tenders/tender/0'),
            ], 202);

        } catch (Exception $e) {

            redirect()->back()->withInput()->with('message', $e->getMessage())->with('code', 400);

        }
    }
}
